pub enum RoundingPriority {
Auto,
MorePrecision,
LessPrecision,
}Variants
Auto
the result from the significant digits property is used.
MorePrecision
the result from the property that results in more precision is used.
LessPrecision
the result from the property that results in less precision is used.