pub struct UseStorageOptions<T, E, D>{ /* private fields */ }Expand description
Implementations
Sourceimpl<T, E, D> UseStorageOptions<T, E, D>
impl<T, E, D> UseStorageOptions<T, E, D>
pub fn listen_to_storage_changes(self, value: bool) -> Self
pub fn filter(self, value: impl Into<FilterOptions>) -> Self
Sourcepub fn delay_during_hydration(self, value: bool) -> Self
pub fn delay_during_hydration(self, value: bool) -> Self
Delays the reading of the value from storage by one animation frame during hydration.
This ensures that during hydration the value is the initial value just like it is on the server
which helps prevent hydration errors. Defaults to false.
Sourceimpl<T, E, D> UseStorageOptions<T, E, D>
impl<T, E, D> UseStorageOptions<T, E, D>
Sourcepub fn on_error(
self,
on_error: impl Fn(UseStorageError<E, D>) + Send + Sync + 'static,
) -> Self
pub fn on_error( self, on_error: impl Fn(UseStorageError<E, D>) + Send + Sync + 'static, ) -> Self
Optional callback whenever an error occurs.
Sourcepub fn initial_value(self, initial: impl Into<MaybeRwSignal<T>>) -> Self
pub fn initial_value(self, initial: impl Into<MaybeRwSignal<T>>) -> Self
Initial value to use when the storage key is not set. Note that this value is read once on creation of the storage hook and not updated again. Accepts a signal and defaults to T::default().