pub struct UseDisplayMediaReturn<StartFn, StopFn>{
pub stream: OptionLocalSignal<Result<MediaStream, JsValue>>,
pub start: StartFn,
pub stop: StopFn,
pub enabled: Signal<bool>,
pub set_enabled: WriteSignal<bool>,
}Expand description
Return type of use_display_media
Fields
stream: OptionLocalSignal<Result<MediaStream, JsValue>>The current MediaStream if it exists.
Initially this is None until start resolved successfully.
In case the stream couldn’t be started, for example because the user didn’t grant permission,
this has the value Some(Err(...)).
start: StartFnStarts the screen streaming. Triggers the ask for permission if not already granted.
stop: StopFnStops the screen streaming
enabled: Signal<bool>A value of true indicates that the returned MediaStream
has resolved successfully and thus the stream is enabled.
set_enabled: WriteSignal<bool>A value of true is the same as calling start() whereas false is the same as calling stop().