UseElementHoverOptions

Struct UseElementHoverOptions 

pub struct UseElementHoverOptions { /* private fields */ }
Implementations

Source

impl UseElementHoverOptions

pub fn delay_enter(self, value: u64) -> Self

The time in ms the mouse has to be hovered over the element before the signal is changed to true. Defaults to 0.

pub fn delay_leave(self, value: u64) -> Self

The time in ms after the mouse has left the element before the signal is changed to false. Defaults to 0.