UseIntlDateTimeFormatOptions

Struct UseIntlDateTimeFormatOptions 

pub struct UseIntlDateTimeFormatOptions { /* private fields */ }

Implementations

Source

impl UseIntlDateTimeFormatOptions

pub fn locales(self, value: Vec<String>) -> Self

A vec of strings, each with a BCP 47 language tag. Please refer to the MDN Docs for more info.

pub fn locale_matcher(self, value: LocaleMatcher) -> Self

The locale matching algorithm to use. Possible values are Lookup and BestFit; the default is BestFit. For information about this option, see the Intl page.

pub fn calendar<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<String>,

The calendar to use, such as "chinese", "gregory", "persian" etc. For a list of the supported calendar types, see the MDN docs.

pub fn day_period<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<DayPeriodFormat>,

The way day periods should be expressed. This option only has an effect if a 12-hour clock (hour_cycle H11 or H12, or hour12 is true) is used. Note that the day period may be displayed even if the hour is not set to be displayed.

pub fn numbering_system<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<String>,

The numbering system to use. Possible values include: "arab", "arabext", "bali", "beng", "deva", "fullwide", "gujr", "guru", "hanidec", "khmr", "knda", "laoo", "latn", "limb", "mlym", "mong", "mymr", "orya", "tamldec", "telu", "thai", "tibt".

pub fn hour12<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<bool>,

Whether to use 12-hour time (as opposed to 24-hour time). The default is locale dependent. This option overrides the hc language tag and/or the hour_cycle option in case both are present.

pub fn hour_cycle<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<HourCycle>,

The hour cycle to use. This option overrides the hc language tag, if both are present, and the hour12 option takes precedence in case both options have been specified.

  • H11: hour system using 0–11; corresponds to midnight starting at 0:00 AM.
  • H12: hour system using 1–12; corresponds to midnight starting at 12:00 AM.
  • H23: hour system using 0–23; corresponds to midnight starting at 0:00.
  • H24: hour system using 1–24; corresponds to midnight starting at 24:00.
pub fn time_zone<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<String>,

The time zone to use. The only value implementations must recognize is "UTC"; the default is the runtime’s default time zone. Implementations may also recognize the time zone names of the IANA time zone database, such as "Asia/Shanghai", "Asia/Kolkata", "America/New_York".

pub fn format_matcher(self, value: FormatMatcher) -> Self

The format matching algorithm to use. Possible values are Basic and BestFit; the default is BestFit. See the MDN docs for details. Only has an effect when using the individual date-time component options (and not UseIntlDateTimeFormatOptions::date_style / UseIntlDateTimeFormatOptions::time_style).

pub fn weekday<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<WeekdayFormat>,

The representation of the weekday.

  • Long: e.g., Thursday
  • Short: e.g., Thu
  • Narrow: e.g., T. Two weekdays may have the same narrow style for some locales (e.g. Tuesday’s narrow style is also T).

Cannot be combined with UseIntlDateTimeFormatOptions::date_style / UseIntlDateTimeFormatOptions::time_style.

pub fn era<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<EraFormat>,

The representation of the era.

  • Long: e.g., Anno Domini
  • Short: e.g., AD
  • Narrow: e.g., A

Cannot be combined with UseIntlDateTimeFormatOptions::date_style / UseIntlDateTimeFormatOptions::time_style.

pub fn year<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<YearFormat>,

The representation of the year.

  • Numeric: e.g., 2012
  • TwoDigit: e.g., 12

Cannot be combined with UseIntlDateTimeFormatOptions::date_style / UseIntlDateTimeFormatOptions::time_style.

pub fn month<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<MonthFormat>,

The representation of the month.

  • Numeric: e.g., 3
  • TwoDigit: e.g., 03
  • Long: e.g., March
  • Short: e.g., Mar
  • Narrow: e.g., M. Two months may have the same narrow style for some locales (e.g. May’s narrow style is also M).

Cannot be combined with UseIntlDateTimeFormatOptions::date_style / UseIntlDateTimeFormatOptions::time_style.

pub fn day<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<DayFormat>,

The representation of the day.

  • Numeric: e.g., 1
  • TwoDigit: e.g., 01

Cannot be combined with UseIntlDateTimeFormatOptions::date_style / UseIntlDateTimeFormatOptions::time_style.

pub fn hour<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<TimeNumericFormat>,

The representation of the hour.

  • Numeric: e.g., 1
  • TwoDigit: e.g., 01

Cannot be combined with UseIntlDateTimeFormatOptions::date_style / UseIntlDateTimeFormatOptions::time_style.

pub fn minute<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<TimeNumericFormat>,

The representation of the minute.

  • Numeric: e.g., 1
  • TwoDigit: e.g., 01

Cannot be combined with UseIntlDateTimeFormatOptions::date_style / UseIntlDateTimeFormatOptions::time_style.

pub fn second<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<TimeNumericFormat>,

The representation of the second.

  • Numeric: e.g., 1
  • TwoDigit: e.g., 01

Cannot be combined with UseIntlDateTimeFormatOptions::date_style / UseIntlDateTimeFormatOptions::time_style.

pub fn fractional_second_digits<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<u8>,

The number of digits used to represent fractions of a second (any additional digits are truncated). Possible values are from 1 to 3.

pub fn time_zone_name<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<TimeZoneNameFormat>,

The localized representation of the time zone name.

  • Long: long localized form (e.g., Pacific Standard Time).
  • Short: short localized form (e.g.: PST).
  • ShortOffset: short localized GMT format (e.g., GMT-8).
  • LongOffset: long localized GMT format (e.g., GMT-0800).
  • ShortGeneric: short generic non-location format (e.g.: PT).
  • LongGeneric: long generic non-location format (e.g.: Pacific Time).
pub fn date_style<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<DateTimeStyle>,

The date formatting length. Cannot be combined with the individual date-time component options (weekday, era, year, month, day, hour, minute, second, fractional_second_digits, time_zone_name, day_period).

Possible values are Full, Long, Medium and Short.

pub fn time_style<OptionInnerType>( self, value: impl Into<Option<OptionInnerType>>, ) -> Self
where OptionInnerType: Into<DateTimeStyle>,

The time formatting length. Cannot be combined with the individual date-time component options (weekday, era, year, month, day, hour, minute, second, fractional_second_digits, time_zone_name, day_period).

Possible values are Full, Long, Medium and Short.

Source

impl UseIntlDateTimeFormatOptions

pub fn locale(self, locale: &str) -> Self

A string with a BCP 47 language tag. Please refer to the MDN Docs for more info.