pub struct UseScrollReturn<SetXFn, SetYFn, MFn>where
SetXFn: Fn(f64) + Clone + Send + Sync,
SetYFn: Fn(f64) + Clone + Send + Sync,
MFn: Fn() + Clone + Send + Sync,{
pub x: Signal<f64>,
pub set_x: SetXFn,
pub y: Signal<f64>,
pub set_y: SetYFn,
pub is_scrolling: Signal<bool>,
pub arrived_state: Signal<Directions>,
pub directions: Signal<Directions>,
pub measure: MFn,
}Expand description
The return value of use_scroll.
Fields
x: Signal<f64>X coordinate of scroll position
set_x: SetXFnSets the value of x. This does also scroll the element.
y: Signal<f64>Y coordinate of scroll position
set_y: SetYFnSets the value of y. This does also scroll the element.
is_scrolling: Signal<bool>Is true while the element is being scrolled.
arrived_state: Signal<Directions>Sets the field that represents a direction to true if the element is scrolled all the way to that side.
directions: Signal<Directions>The directions in which the element is being scrolled are set to true.
measure: MFnRe-evaluates the arrived_state.