pub struct UseIntlDateTimeFormatReturn;Expand description
Return type of use_intl_datetime_format.
Implementations
Sourceimpl UseIntlDateTimeFormatReturn
impl UseIntlDateTimeFormatReturn
Sourcepub fn format<Tz>(
&self,
date: impl Into<Signal<DateTime<Tz>>>,
) -> Signal<String>
pub fn format<Tz>( &self, date: impl Into<Signal<DateTime<Tz>>>, ) -> Signal<String>
Formats a date according to the locale and formatting options of this Intl.DateTimeFormat object.
See use_intl_datetime_format for more information.
In the browser this uses SendWrapper internally so the returned signal can only be used on
the same thread where this method was called.
Sourcepub fn format_range<TzStart, TzEnd>(
&self,
start: impl Into<Signal<DateTime<TzStart>>>,
end: impl Into<Signal<DateTime<TzEnd>>>,
) -> Signal<String>
pub fn format_range<TzStart, TzEnd>( &self, start: impl Into<Signal<DateTime<TzStart>>>, end: impl Into<Signal<DateTime<TzEnd>>>, ) -> Signal<String>
Formats a range of dates according to the locale and formatting options of this
Intl.DateTimeFormat object.
let start = Utc.with_ymd_and_hms(2007, 1, 10, 10, 0, 0).unwrap();
let end = Utc.with_ymd_and_hms(2008, 1, 10, 11, 0, 0).unwrap();
let date_time_format = use_intl_datetime_format(
UseIntlDateTimeFormatOptions::default()
.locale("en-US")
.year(YearFormat::Numeric)
.month(MonthFormat::Short)
.day(DayFormat::Numeric),
);
let formatted = date_time_format.format_range(start, end); // "Jan 10, 2007 – Jan 10, 2008"Auto Trait Implementations
impl Freeze for UseIntlDateTimeFormatReturn
impl RefUnwindSafe for UseIntlDateTimeFormatReturn
impl Send for UseIntlDateTimeFormatReturn
impl Sync for UseIntlDateTimeFormatReturn
impl Unpin for UseIntlDateTimeFormatReturn
impl UnsafeUnpin for UseIntlDateTimeFormatReturn
impl UnwindSafe for UseIntlDateTimeFormatReturn